@@ -1,4 +1,4 @@
 """Create, manipulate, read, and write time-series data with a customised Virgo class
 
 """
-from .gwdatamanager import GwDataManager, GlitchDB
+from .gwdatamanager import GwDataManager
\ No newline at end of file
