@@ -8,7 +8,7 @@ It should be kept up to date with the location of the various ffl files.
 # ----- Virgo -----
 V1_raw = "/virgoData/ffl/raw.ffl"
 V1_trend = "/virgoData/ffl/trend.ffl"
-V1_trend100 = "/virgoData/ffl/trend100.ffl"
+V1_trend100 = "/virgoData/ffl/trend100s.ffl"
 
 
 # ----- LIGO -----
@@ -25,4 +25,4 @@ L1_O3a = "/virgoData/ffl/O3A/L1Online.ffl"
 
 # ----- UniPi -----
 unipi_O3 = "/virgoData/ffl/unipi_O3.ffl"         # for rawdata buffer copy
-unipi_raw = "/virgoData/ffl/unipi_rawarch.ffl"    # for rawdata archive copy
+unipi_arch = "/virgoData/ffl/unipi_rawarch.ffl"    # for rawdata archive copy
